@@ -18,6 +18,7 @@ from petisco.persistence.sql.errors import (
     EntityAlreadyExistError,
     EntityNotFoundError,
     EntitiesNotFoundError,
+    UserNotFoundError,
 )
 
 
@@ -35,6 +36,19 @@ class SqlRepository(IRepository, metaclass=ABCMeta):
 
         return Success(self.internal_client_id)
 
+    def get_sql_internal_user_id(self, session, model) -> Result[int, Error]:
+        if not hasattr(self, "internal_user_id"):
+            internal_user_id = (
+                session.query(model.id)
+                .filter(model.user_id == self.get_user_id_value())
+                .first()
+            )
+            if not internal_user_id:
+                return Failure(UserNotFoundError(self.get_user_id()))
+            self.internal_user_id = internal_user_id.id
+
+        return Success(self.internal_user_id)
+
     @classmethod
     def fail_if_entity_already_exist(
         cls, model, entity_id: Uuid, result_error: Error = None
