@@ -1,7 +1,7 @@
 from time import sleep
 
 import pytest
-from meiga import isSuccess, Result, Error, isFailure
+from meiga import isSuccess, Result, Error, isFailure, BoolResult
 
 from petisco import Event, EventSubscriber
 
@@ -23,7 +23,7 @@ def test_should_publish_consume_from_store_queue_from_rabbitmq():
 
     spy = SpyEvents()
 
-    def assert_consumer_event_store(event: Event) -> Result[bool, Error]:
+    def assert_consumer_event_store(event: Event) -> BoolResult:
         spy.append(event)
         return isSuccess
 
@@ -54,10 +54,11 @@ def test_should_publish_consume_from_store_queue_from_rabbitmq():
 @pytest.mark.parametrize(
     "max_retries_allowed,expected_number_event_consumed,simulated_results",
     [
-        (1, 1, [isFailure, isSuccess]),
-        (2, 2, [isFailure, isFailure, isSuccess]),
-        (3, 3, [isFailure, isFailure, isFailure, isSuccess]),
-        (4, 4, [isFailure, isFailure, isFailure, isFailure, isSuccess]),
+        (0, 1, [isFailure]),
+        (1, 2, [isFailure, isSuccess]),
+        (2, 3, [isFailure, isFailure, isSuccess]),
+        (3, 4, [isFailure, isFailure, isFailure, isSuccess]),
+        (4, 5, [isFailure, isFailure, isFailure, isFailure, isSuccess]),
     ],
 )
 def test_should_publish_consume_and_retry_from_store_queue_from_rabbitmq(
@@ -72,7 +73,7 @@ def test_should_publish_consume_and_retry_from_store_queue_from_rabbitmq(
 
     event = EventUserCreatedMother.random()
 
-    configurer = RabbitMqEventConfigurerMother.with_ttl_10ms()
+    configurer = RabbitMqEventConfigurerMother.with_retry_ttl_10ms()
     configurer.configure_event(event)
 
     bus = RabbitMqEventBusMother.default()
@@ -99,10 +100,11 @@ def test_should_publish_consume_and_retry_from_store_queue_from_rabbitmq(
 @pytest.mark.parametrize(
     "max_retries_allowed,expected_number_event_consumed,simulated_results",
     [
-        (1, 1, [isFailure, isSuccess]),
-        (2, 2, [isFailure, isFailure, isSuccess]),
-        (3, 3, [isFailure, isFailure, isFailure, isSuccess]),
-        (4, 4, [isFailure, isFailure, isFailure, isFailure, isSuccess]),
+        (0, 1, [isFailure]),
+        (1, 2, [isFailure, isSuccess]),
+        (2, 3, [isFailure, isFailure, isSuccess]),
+        (3, 4, [isFailure, isFailure, isFailure, isSuccess]),
+        (4, 5, [isFailure, isFailure, isFailure, isFailure, isSuccess]),
     ],
 )
 def test_should_publish_consume_and_retry_from_store_queue_not_affecting_other_queue_from_rabbitmq_when_fail_event_storer_consumer(
@@ -129,7 +131,7 @@ def test_should_publish_consume_and_retry_from_store_queue_not_affecting_other_q
         )
     ]
 
-    configurer = RabbitMqEventConfigurerMother.with_ttl_10ms()
+    configurer = RabbitMqEventConfigurerMother.with_retry_ttl_10ms()
     configurer.configure_subscribers(subscribers)
 
     bus = RabbitMqEventBusMother.default()
@@ -182,7 +184,7 @@ def test_should_publish_two_event_and_consume_from_store_queue_from_rabbitmq(
     event_1 = EventUserCreatedMother.random()
     event_2 = EventUserCreatedMother.random()
 
-    configurer = RabbitMqEventConfigurerMother.with_ttl_10ms()
+    configurer = RabbitMqEventConfigurerMother.with_retry_ttl_10ms()
     configurer.configure_event(event_1)
     configurer.configure_event(event_2)
 
